Documentation
¶
Overview ¶
Package encrypted provides an encrypted configuration source wrapper that automatically encrypts and decrypts data using the secrets interface.
Package encrypted provides an encrypted configuration source wrapper that automatically encrypts and decrypts data using the secrets interface.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewSource ¶
NewSource creates a new encrypted source that wraps an underlying source. The encrypted source automatically decrypts data on Read and encrypts data on Write.
Required options:
- WithSecret: sets the encryption/decryption provider
- WithSource: sets the underlying data source
Types ¶
Source Files
¶
- encrypted.go
- options.go
Click to show internal directories.
Click to hide internal directories.