Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewCallWrapper ¶
func NewCallWrapper(opts ...Option) client.CallWrapper
NewCallWrapper creates a new call wrapper for security checks
func NewClientWrapper ¶
NewClientWrapper creates a new client wrapper for security checks
func NewHandlerWrapper ¶
func NewHandlerWrapper(opts ...Option) server.HandlerWrapper
NewHandlerWrapper creates a new handler wrapper for basic security checks
Types ¶
type Config ¶
Source Files
¶
- options.go
- wrappers.go
Click to show internal directories.
Click to hide internal directories.